function fm = homog1d_embed(F, w, x)

% function fm = homog1d_embed(F, w, x)
%
% generates a homogeneous feature map of x (1D input) using
% frequencies F with weights w
% each element in x is mapped to a feature map
% represented by a column in fm
%
% For more details see Chum: Low Dimensional Explicit Feature Maps, ICCV'15
% http://cmp.felk.cvut.cz/~chum
% (C) Ondrej Chum 2015

x = x(:)';
fm = [];

for i = 1:length(F);
  fm = [fm; sqrt(w(i)) * sqrt(x) .* cos(F(i) * log(x))];
  if F(i) > 0
      fm = [fm; sqrt(w(i)) * sqrt(x) .* sin(F(i) * log(x))];
  end
end

fm(isnan(fm)) = 0;
