function o = ker1d_embed(F, w, x)

% function o = ker1d_embed(F, w, x)
%
% generates a homogeneous feature map of x (1D input) using
% frequencies F with weights w
% each element in x is mapped to a feature map
% represented by a column in o
%
% For more details see Chum: Low Dimensional Explicit Feature Maps, ICCV'15
% http://cmp.felk.cvut.cz/~chum
% (C) Ondrej Chum 2015

o = [];
for i = 1:length(F);
    o = [o; sqrt(w(i)) * cos(F(i) * x)];
    if F(i) > 0
        o = [o; sqrt(w(i)) * sin(F(i) * x)];
    end
end

o(isnan(o)) = 0;