function [C, f] = ldfm_datamatrix (X, F)

% [C, f] = ldfm_datamatrix (X, F)
%
% Samples cosines of frequencies in F at domain specified in X
% X domain matrix structure
% F frequency matrix, each column is frqs for all dimensions
%
% Output:
%     matrix C, so that C * w' = kernel signature
%     f - dimensionality of the feature map corresponding to each row of C
%
% For more details see Chum: Low Dimensional Explicit Feature Maps, ICCV'15
% http://cmp.felk.cvut.cz/~chum
% (C) Ondrej Chum 2015


if nargin < 3
    pderiv = 0;
end

if isfield(X,'domain')
    x = X.domain;
else
    x = X;
end
npoints = size(x,2);

nfrq =  size(F, 2);
dims =  size(F, 1);

C = ones(npoints,nfrq);
f = ones(nfrq, 1);

for i = 1 : nfrq
    for d = 1 : dims
     if F(d,i)   
       C(:,i) = C(:,i) .* cos(F(d,i)*x(d,:)');
       f(i) = 2 * f(i);
     end
    end
 end