function [C, u] = ldfm_datapardif (X, F, pderiv)

% [C, u] = ldfm_datapardif (X, F, pderiv)
%
% computes partial derivation over dimension specified in pderiv
% X domain matrix structure
% F frequency matrix, each column is frqs for all dimensions
%
% For more details see Chum: Low Dimensional Explicit Feature Maps, ICCV'15
% http://cmp.felk.cvut.cz/~chum
% (C) Ondrej Chum 2015


x = X.domain;
npoints = size(x,2);

nfrq =  size(F, 2);
dims =  size(F, 1);

C = ones(npoints,nfrq);
f = ones(nfrq, 1);

for i = 1 : nfrq
    for d = 1 : dims
     if d == pderiv   
       C(:,i) = C(:,i) .* x(d,:)' .* -sin(F(d,i)*x(d,:)');
     else
       C(:,i) = C(:,i) .* cos(F(d,i)*x(d,:)');
     end
    end
end
 
u = find(F(pderiv,:) ~= 0);
C = C(:,u);
